###############################
LeCroy T3DSO1204 Oscilloscope
###############################

.. autoclass:: pymeasure.instruments.lecroy.LeCroyT3DSO1204
    :members:
    :show-inheritance:
    :inherited-members:
    :exclude-members:

.. autoclass:: pymeasure.instruments.lecroy.lecroyT3DSO1204.LeCroyT3DSO1204Channel
    :members:
    :show-inheritance:

